# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/bata/data/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/bata/data/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Bata\\Data\\": "packages/bata/data/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Bata\Data\Providers\DataServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Data'  => Bata\Data\Facades\Data::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Bata\\DataTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Bata\Data\Providers\DataServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Bata\Data\Providers\DataServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Bata\Data\Providers\DataServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/data/{modulename}

**User**

    http://path-to-route-folder/user/data/{modulename}

**Public**

    http://path-to-route-folder/data


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/data/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/data/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/data/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/data/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/data/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/data/{modulename}/{slug}
    METHOD: GET